#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
@author: Stefan Hiemer
"""

import numpy as np 
from scipy.special import expi 

def int_eta_dz(z,A,B):
    return A*(expi(-A/(B+z))-expi(-A/(B))) + (z+B)*np.exp(-A/(B+z)) \
           - B*np.exp(-A/B)
           
def int_etaz_dz(z,A,B):
    
    term1 = A*(A+2*B)*(expi(-A/B)-expi(-A/(B+z)))
    term2 = B*(A+B)*np.exp(-A/B) - (B+z)*(A+B-z)*np.exp(-A/(B+z))
    
    return 0.5*(term1+term2)
           
def intint_eta_dzdz(z,A,B):
    term1 = A*(A + 2*(B+z))*expi(-A/(B+z))
    term2 = (B+z)*(A+B+z)*np.exp(-A/(B+z)) 
    
    c1 = A*expi(-A/B) + B*np.exp(-A/B) 
                            
    c2 = A*(A+ 2*B)*expi(-A/B)+B*(A+B)*np.exp(-A/B)
    
    return 0.5 * (term1 + term2 - 2*c1*z - c2) 

def intint_etaz_dzdz(z,A,B):
    term1 = A*(A**2 + 6*A*B + 6*B**2 + 3*(A+2*B)*z)*expi(-A/(B+z))
    term2 = (B+z)*(A**2 + 5*A*B + 2*B**2 + (B + 2*A)*z - z**2)*np.exp(-A/(B+z))
    
    
    c1 =  A*(A+2*B)*expi(-A/B) + B*(A+B)*np.exp(-A/B)
                            
    c2 = A*(A**2 + 6*A*B + 6*B**2)*expi(-A/(B))+\
         B*(A**2 + 5*A*B + 2*B**2)*np.exp(-A/(B))
    
    return (c2-term1 + term2)/6 + c1*z 

def eta_1(z, A,B):
    return np.exp(-A/(B+z))

def eta_1x(z, A,B):
    return z*np.exp(-A/(B+z))

def test_integrals():
    from scipy.integrate import quad
    
    A = 2
    B = 5
    z = 10 
    
    if not np.isclose(int_eta_dz(z,A,B),quad(eta_1,a=0,b=z,args=(A,B))[0]):
        raise ValueError("Viscosity integral wrong.")
    
    if not np.isclose(int_etaz_dz(z,A,B),quad(eta_1x,a=0,b=z,args=(A,B))[0]):
        raise ValueError("Locally weighted viscosity integral wrong.")
    
    if not np.isclose(intint_eta_dzdz(z,A,B),quad(int_eta_dz,0,z, args=(A,B))[0]):
        raise ValueError("Viscosity double integral wrong.")
    
    if not np.isclose(intint_etaz_dzdz(z,A,B),quad(int_etaz_dz,a=0,b=z,args=(A,B))[0]):
        raise ValueError("Locally weighted viscosity double integral wrong.")
        
    return 

if __name__=="__main__":
    test_integrals()
